@@ -2,7 +2,7 @@
 from __future__ import absolute_import
 from django.utils.encoding import smart_str
 from geopy import geocoders
-from geopy.geocoders.base import GeocoderResultError
+from geopy.exc import GeocoderServiceError
 
 class Error(Exception):
     pass
@@ -17,5 +17,5 @@ def google_v3(address):
         g = geocoders.GoogleV3()
         address = smart_str(address)
         return g.geocode(address, exactly_one=False)[0]
-    except (UnboundLocalError, ValueError, GeocoderResultError) as e:
+    except (UnboundLocalError, ValueError, GeocoderServiceError) as e:
         raise Error(e)
